==> haskell-quic-0.1.26-4-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quic
version:              0.1.26
visibility:           public
id:                   quic-0.1.26-H0HytmFNAweFkRR9zmzsb4
key:                  quic-0.1.26-H0HytmFNAweFkRR9zmzsb4
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             QUIC
description:
    Library for QUIC: A UDP-Based Multiplexed and Secure Transport

category:             Web
abi:                  716d132720929ccc1e8073d79d70b266
exposed:              True
exposed-modules:
    Network.QUIC Network.QUIC.Client Network.QUIC.Internal
    Network.QUIC.Server

hidden-modules:
    Network.QUIC.Client.Reader Network.QUIC.Client.Run
    Network.QUIC.Closer Network.QUIC.Common Network.QUIC.Config
    Network.QUIC.Connection Network.QUIC.Connection.Crypto
    Network.QUIC.Connection.Migration Network.QUIC.Connection.Misc
    Network.QUIC.Connection.PacketNumber Network.QUIC.Connection.Queue
    Network.QUIC.Connection.Role Network.QUIC.Connection.State
    Network.QUIC.Connection.Stream Network.QUIC.Connection.StreamTable
    Network.QUIC.Connection.Timeout Network.QUIC.Connection.Types
    Network.QUIC.Connector Network.QUIC.Crypto
    Network.QUIC.Crypto.Fusion Network.QUIC.Crypto.Keys
    Network.QUIC.Crypto.Nite Network.QUIC.Crypto.Types
    Network.QUIC.Crypto.Utils Network.QUIC.Event Network.QUIC.Exception
    Network.QUIC.Handshake Network.QUIC.IO Network.QUIC.Imports
    Network.QUIC.Info Network.QUIC.Logger Network.QUIC.Packet
    Network.QUIC.Packet.Decode Network.QUIC.Packet.Decrypt
    Network.QUIC.Packet.Encode Network.QUIC.Packet.Frame
    Network.QUIC.Packet.Header Network.QUIC.Packet.Number
    Network.QUIC.Packet.Token Network.QUIC.Parameters
    Network.QUIC.QLogger Network.QUIC.Qlog Network.QUIC.Receiver
    Network.QUIC.Recovery Network.QUIC.Recovery.Constants
    Network.QUIC.Recovery.Detect Network.QUIC.Recovery.Interface
    Network.QUIC.Recovery.LossRecovery Network.QUIC.Recovery.Metrics
    Network.QUIC.Recovery.Misc Network.QUIC.Recovery.PeerPacketNumbers
    Network.QUIC.Recovery.Persistent Network.QUIC.Recovery.Release
    Network.QUIC.Recovery.Timer Network.QUIC.Recovery.Types
    Network.QUIC.Recovery.Utils Network.QUIC.Sender
    Network.QUIC.Server.Reader Network.QUIC.Server.Run
    Network.QUIC.Stream Network.QUIC.Stream.Frag
    Network.QUIC.Stream.Misc Network.QUIC.Stream.Queue
    Network.QUIC.Stream.Reass Network.QUIC.Stream.Skew
    Network.QUIC.Stream.Table Network.QUIC.Stream.Types
    Network.QUIC.TLS Network.QUIC.Types Network.QUIC.Types.Ack
    Network.QUIC.Types.CID Network.QUIC.Types.Constants
    Network.QUIC.Types.Error Network.QUIC.Types.Exception
    Network.QUIC.Types.Frame Network.QUIC.Types.Info
    Network.QUIC.Types.Integer Network.QUIC.Types.Packet
    Network.QUIC.Types.Queue Network.QUIC.Types.Resumption
    Network.QUIC.Types.Time Network.QUIC.Utils Network.QUIC.Windows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/quic-0.1.26
library-dirs:         /usr/lib/ghc-9.6.6/site-local/quic-0.1.26
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/quic-0.1.26
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quic
hs-libraries:         HSquic-0.1.26-H0HytmFNAweFkRR9zmzsb4
depends:
    array-0.5.6.0 base-4.18.2.1
    base16-bytestring-1.0.2.0-Dwd5n4mSUH32rjuqPFOreR
    bytestring-0.11.5.3 containers-0.6.7
    crypto-token-0.1.2-IQscVG2wpVu806DTaWJZS
    crypton-1.0.4-11gen3PFWz54w2m32bVEwY
    crypton-x509-1.7.7-36kCqNSNK3p1rkA4mLjsoT
    crypton-x509-system-1.6.7-AlhozJnZLRBLBROfMMJw3u
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc
    fast-logger-3.2.4-CxqhiTCbe4z8Z1RtKJsh15 filepath-1.4.300.1
    iproute-1.7.15-8MQv32arzXu8ybbx4AUApr
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    network-byte-order-0.1.7-KOrHLkTNWo52qSQao8kAgk
    network-control-0.1.3-Hts72k10EnKIVPk1rEcNCA
    network-udp-0.0.0-EL7cgW0kYJA3uRLstuwdoJ
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    serialise-0.2.6.1-H8jGFFiph3l4AopTRNckmn stm-2.5.1.0
    tls-2.0.6-HHKVvNcSfLyJGme2UrIiax
    unix-time-0.4.17-Hz2xrJUYyRaFNdjGOcUMp2
    unliftio-0.2.25.1-IdlKKcTSqjp7zAgGJLE7Xd
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/haskell-quic/html/quic.haddock
haddock-html:         /usr/share/doc/haskell-quic/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quic-0.1.26-6-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quic
version:              0.1.26
visibility:           public
id:                   quic-0.1.26-7WHAlB5OPHxDDWxQdvVEEO
key:                  quic-0.1.26-7WHAlB5OPHxDDWxQdvVEEO
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             QUIC
description:
    Library for QUIC: A UDP-Based Multiplexed and Secure Transport

category:             Web
abi:                  3bbc4e39f439c4be5e29f90ffc4dbe57
exposed:              True
exposed-modules:
    Network.QUIC Network.QUIC.Client Network.QUIC.Internal
    Network.QUIC.Server

hidden-modules:
    Network.QUIC.Client.Reader Network.QUIC.Client.Run
    Network.QUIC.Closer Network.QUIC.Common Network.QUIC.Config
    Network.QUIC.Connection Network.QUIC.Connection.Crypto
    Network.QUIC.Connection.Migration Network.QUIC.Connection.Misc
    Network.QUIC.Connection.PacketNumber Network.QUIC.Connection.Queue
    Network.QUIC.Connection.Role Network.QUIC.Connection.State
    Network.QUIC.Connection.Stream Network.QUIC.Connection.StreamTable
    Network.QUIC.Connection.Timeout Network.QUIC.Connection.Types
    Network.QUIC.Connector Network.QUIC.Crypto
    Network.QUIC.Crypto.Fusion Network.QUIC.Crypto.Keys
    Network.QUIC.Crypto.Nite Network.QUIC.Crypto.Types
    Network.QUIC.Crypto.Utils Network.QUIC.Event Network.QUIC.Exception
    Network.QUIC.Handshake Network.QUIC.IO Network.QUIC.Imports
    Network.QUIC.Info Network.QUIC.Logger Network.QUIC.Packet
    Network.QUIC.Packet.Decode Network.QUIC.Packet.Decrypt
    Network.QUIC.Packet.Encode Network.QUIC.Packet.Frame
    Network.QUIC.Packet.Header Network.QUIC.Packet.Number
    Network.QUIC.Packet.Token Network.QUIC.Parameters
    Network.QUIC.QLogger Network.QUIC.Qlog Network.QUIC.Receiver
    Network.QUIC.Recovery Network.QUIC.Recovery.Constants
    Network.QUIC.Recovery.Detect Network.QUIC.Recovery.Interface
    Network.QUIC.Recovery.LossRecovery Network.QUIC.Recovery.Metrics
    Network.QUIC.Recovery.Misc Network.QUIC.Recovery.PeerPacketNumbers
    Network.QUIC.Recovery.Persistent Network.QUIC.Recovery.Release
    Network.QUIC.Recovery.Timer Network.QUIC.Recovery.Types
    Network.QUIC.Recovery.Utils Network.QUIC.Sender
    Network.QUIC.Server.Reader Network.QUIC.Server.Run
    Network.QUIC.Stream Network.QUIC.Stream.Frag
    Network.QUIC.Stream.Misc Network.QUIC.Stream.Queue
    Network.QUIC.Stream.Reass Network.QUIC.Stream.Skew
    Network.QUIC.Stream.Table Network.QUIC.Stream.Types
    Network.QUIC.TLS Network.QUIC.Types Network.QUIC.Types.Ack
    Network.QUIC.Types.CID Network.QUIC.Types.Constants
    Network.QUIC.Types.Error Network.QUIC.Types.Exception
    Network.QUIC.Types.Frame Network.QUIC.Types.Info
    Network.QUIC.Types.Integer Network.QUIC.Types.Packet
    Network.QUIC.Types.Queue Network.QUIC.Types.Resumption
    Network.QUIC.Types.Time Network.QUIC.Utils Network.QUIC.Windows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/quic-0.1.26
library-dirs:         /usr/lib/ghc-9.6.6/site-local/quic-0.1.26
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/quic-0.1.26
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quic
hs-libraries:         HSquic-0.1.26-7WHAlB5OPHxDDWxQdvVEEO
depends:
    array-0.5.6.0 base-4.18.2.1
    base16-bytestring-1.0.2.0-ARBAmNNbyxLEDoUwDjra0R
    bytestring-0.11.5.3 containers-0.6.7
    crypto-token-0.1.2-2d88nFd0vTmHgdc2NliHLH
    crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI
    crypton-x509-1.7.7-6vuhyPxGrsd7bUuwSROapz
    crypton-x509-system-1.6.7-DQHBNlA1dz6FrhIVkM7QX0
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc
    fast-logger-3.2.4-AXHM12y5MtZKIIwsnmTfyz filepath-1.4.300.1
    iproute-1.7.15-G8PIBt0bMmIHonL1qb456T
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    network-byte-order-0.1.7-KOrHLkTNWo52qSQao8kAgk
    network-control-0.1.3-FQv7ufgIESmKhgBnRdMPqy
    network-udp-0.0.0-BkltWFFDBohIZQT572OUWY
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    serialise-0.2.6.1-1dianXJhkpM97MZAKPCh4L stm-2.5.1.0
    tls-2.0.6-CMnie4Wyps5DmePV9nSMbU
    unix-time-0.4.17-1fbhzfcTn8QIpITXkAFa5Z
    unliftio-0.2.25.1-6Q6KWrgvoh1DxBXv7luml2
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/haskell-quic/html/quic.haddock
haddock-html:         /usr/share/doc/haskell-quic/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
